==> phpnuke-5.5.tgz: www/phpnuke/html/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","ISO-8859-1");
define("_SEARCH","Leita");
define("_LOGIN","Innskrning");
define("_WRITES","skrifar");
define("_POSTEDON","Sent inn");
define("_NICKNAME","Notandanafn");
define("_PASSWORD","Lykilor");
define("_WELCOMETO","Velkomin(n) ");
define("_EDIT","Breyta");
define("_DELETE","Eya");
define("_POSTEDBY","Sent inn af");
define("_READS","sinnum lesin");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Til baka</a> ]");
define("_COMMENTS","athugasemdir");
define("_PASTARTICLES","Fyrri greinar");
define("_OLDERARTICLES","Eldri greinar");
define("_BY","fr");
define("_ON","ann");
define("_LOGOUT","Skr ig t");
define("_WAITINGCONT","Efni  bir");
define("_SUBMISSIONS","Frttir");
define("_WREVIEWS","Umsagnir  bi");
define("_WLINKS","Veftenglar  bi");
define("_EPHEMERIDS","Dagbkarbrot");
define("_ONEDAY","essi dagur  sgunni...");
define("_ASREGISTERED","Ertu ekki enn me agang?  getur <a href=\"modules.php?name=Your_Account\">skr ig inn</a>. Sem skrur notandi getur  til dmis breytt tliti sunnar og sent inn frttir og athugasemdir undir nu nafni.");
define("_MENUFOR","Valmynd fyrir");
define("_NOBIGSTORY","Frtt dagsins er ekki enn bin a sj dagsins ljs.");
define("_BIGSTORY","Mest lesna frttin  dag er:");
define("_SURVEY","Knnunin");
define("_POLLS","Kannanir");
define("_PCOMMENTS","Athugasemdir:");
define("_RESULTS","Niurstur");
define("_HREADMORE","lesa meira...");
define("_CURRENTLY"," augnablikinu eru");
define("_GUESTS","gestir og");
define("_MEMBERS","skrir notendur tengdir.");
define("_YOUARELOGGED"," ert skrur inn sem");
define("_YOUHAVE"," tt inni");
define("_PRIVATEMSG","skilabo.");
define("_YOUAREANON"," er ekki skr(ur).   getur skr ig keypis me v a smella <a href=\"modules.php?name=Your_Account\">hrna</a>");
define("_NOTE","Ath:");
define("_ADMIN","Kerfisstjrn:");
define("_WERECEIVED","Hj okkur hafa veri skoaar");
define("_PAGESVIEWS","sur san ");
define("_TOPIC","Efnisflokkur");
define("_UDOWNLOADS","Skrasvi");
define("_VOTE","Kjsa");
define("_VOTES","Atkvi");
define("_MVIEWADMIN","Sn: Aeins kerfisstjrar");
define("_MVIEWUSERS","Sn: Aeins skrir notendur");
define("_MVIEWANON","Sn: Aeins skrir notendur");
define("_MVIEWALL","Sn: Allir gestir");
define("_EXPIRELESSHOUR","Rennur t eftir minna en eina klukkustund");
define("_EXPIREIN","Rennur t eftir");
define("_HTTPREFERERS","HTTP Tilvsanir");
define("_UNLIMITED","takmarka");
define("_HOURS","klukkustundir");
define("_RSSPROBLEM"," augnablikinu virist vera vandaml vi a skja fyrirsagnir fr essari su");
define("_SELECTLANGUAGE","Veldu tunguml");
define("_SELECTGUILANG","Veldu tunguml sunnar:");
define("_NONE","Enginn");
define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
define("_NOACTIVEMODULES","Inactive Modules");
define("_FORADMINTESTS","(for Admin tests)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
#define("_DATESTRING","%A, %B %d @ %T %Z");
#define("_DATESTRING2","%A, %B %d");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CHARSET","ISO-8859-1");
define("_SEARCH","Leita");
define("_LOGIN","Innskrning");
define("_WRITES","skrifar");
define("_POSTEDON","Sent inn");
define("_NICKNAME","Notandanafn");
define("_PASSWORD","Lykilor");
define("_WELCOMETO","Velkomin(n) ");
define("_EDIT","Breyta");
define("_DELETE","Eya");
define("_POSTEDBY","Sent inn af");
define("_READS","sinnum lesin");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\">Til baka</a> ]");
define("_COMMENTS","athugasemdir");
define("_PASTARTICLES","Fyrri greinar");
define("_OLDERARTICLES","Eldri greinar");
define("_BY","fr");
define("_ON","ann");
define("_LOGOUT","Skr ig t");
define("_WAITINGCONT","Efni  bir");
define("_SUBMISSIONS","Frttir");
define("_WREVIEWS","Umsagnir  bi");
define("_WLINKS","Veftenglar  bi");
define("_EPHEMERIDS","Dagbkarbrot");
define("_ONEDAY","essi dagur  sgunni...");
define("_ASREGISTERED","Ertu ekki enn me agang?  getur <a href=\"modules.php?name=Your_Account\">skr ig inn</a>. Sem skrur notandi getur  til dmis breytt tliti sunnar og sent inn frttir og athugasemdir undir nu nafni.");
define("_MENUFOR","Valmynd fyrir");
define("_NOBIGSTORY","Frtt dagsins er ekki enn bin a sj dagsins ljs.");
define("_BIGSTORY","Mest lesna frttin  dag er:");
define("_SURVEY","Knnunin");
define("_POLLS","Kannanir");
define("_PCOMMENTS","Athugasemdir:");
define("_RESULTS","Niurstur");
define("_HREADMORE","lesa meira...");
define("_CURRENTLY"," augnablikinu eru");
define("_GUESTS","gestir og");
define("_MEMBERS","skrir notendur tengdir.");
define("_YOUARELOGGED"," ert skrur inn sem");
define("_YOUHAVE"," tt inni");
define("_PRIVATEMSG","skilabo.");
define("_YOUAREANON"," er ekki skr(ur).   getur skr ig keypis me v a smella <a href=\"modules.php?name=Your_Account\">hrna</a>");
define("_NOTE","Ath:");
define("_ADMIN","Kerfisstjrn:");
define("_WERECEIVED","Hj okkur hafa veri skoaar");
define("_PAGESVIEWS","sur san ");
define("_TOPIC","Efnisflokkur");
define("_UDOWNLOADS","Skrasvi");
define("_VOTE","Kjsa");
define("_VOTES","Atkvi");
define("_MVIEWADMIN","Sn: Aeins kerfisstjrar");
define("_MVIEWUSERS","Sn: Aeins skrir notendur");
define("_MVIEWANON","Sn: Aeins skrir notendur");
define("_MVIEWALL","Sn: Allir gestir");
define("_EXPIRELESSHOUR","Rennur t eftir minna en eina klukkustund");
define("_EXPIREIN","Rennur t eftir");
define("_HTTPREFERERS","HTTP Tilvsanir");
define("_UNLIMITED","takmarka");
define("_HOURS","klukkustundir");
define("_RSSPROBLEM"," augnablikinu virist vera vandaml vi a skja fyrirsagnir fr essari su");
define("_SELECTLANGUAGE","Veldu tunguml");
define("_SELECTGUILANG","Veldu tunguml sunnar:");
define("_NONE","Enginn");
define("_BLOCKPROBLEM","<center>There is a problem right now with this block.</center>");
define("_BLOCKPROBLEM2","<center>There isn't content right now for this block.</center>");
define("_MODULENOTACTIVE","Sorry, this Module isn't active!");
define("_NOACTIVEMODULES","Inactive Modules");
define("_FORADMINTESTS","(for Admin tests)");
define("_BBFORUMS","Forums");
define("_ACCESSDENIED", "Access Denied");
define("_RESTRICTEDAREA", "You are trying to access to a restricted area.");
define("_MODULEUSERS", "We are Sorry but this section of our site is for <i>Registered Users Only</i><br><br>You can register for free by clicking <a href=\"modules.php?name=Your_Account&op=new_user\">here</a>, then you can<br>access to this section without restrictions. Thanks.<br><br>");
define("_MODULESADMINS", "We are Sorry but this section of our site is for <i>Administrators Only</i><br><br>");
define("_HOME","Home");
define("_HOMEPROBLEM","There is a big problem here: we have not a Homepage!!!");
define("_ADDAHOME","Add a Module in your Home");
define("_HOMEPROBLEMUSER","There is a problem right now on the Homepage. Please check it back later.");
define("_MORENEWS","More in News Section");
define("_ALLCATEGORIES","All Categories");
#define("_DATESTRING","%A, %B %d @ %T %Z");
#define("_DATESTRING2","%A, %B %d");
define("_DATE","Date");
define("_HOUR","Hour");
define("_UMONTH","Month");
define("_YEAR","Year");
define("_JANUARY","January");
define("_FEBRUARY","February");
define("_MARCH","March");
define("_APRIL","April");
define("_MAY","May");
define("_JUNE","June");
define("_JULY","July");
define("_AUGUST","August");
define("_SEPTEMBER","September");
define("_OCTOBER","October");
define("_NOVEMBER","November");
define("_DECEMBER","December");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>
